@@ -1003,7 +1003,7 @@ static inline void zdotu_(doublecomplex *z, integer *n_, doublecomplex *x, integ
 /* > \ingroup realPOsolve */
 
 /*  ===================================================================== */
-/* Subroutine */ int sposvxx_(char *fact, char *uplo, integer *n, integer *
+/* Subroutine */ void sposvxx_(char *fact, char *uplo, integer *n, integer *
 	nrhs, real *a, integer *lda, real *af, integer *ldaf, char *equed, 
 	real *s, real *b, integer *ldb, real *x, integer *ldx, real *rcond, 
 	real *rpvgrw, real *berr, integer *n_err_bnds__, real *
@@ -1029,10 +1029,10 @@ static inline void zdotu_(doublecomplex *z, integer *n_, doublecomplex *x, integ
     extern /* Subroutine */ int xerbla_(char *, integer *, ftnlen);
     real bignum;
     integer infequ;
-    extern /* Subroutine */ int slacpy_(char *, integer *, integer *, real *, 
+    extern /* Subroutine */ void slacpy_(char *, integer *, integer *, real *, 
 	    integer *, real *, integer *);
     real smlnum;
-    extern /* Subroutine */ int slaqsy_(char *, integer *, real *, integer *, 
+    extern /* Subroutine */ void slaqsy_(char *, integer *, real *, integer *, 
 	    real *, real *, real *, char *), spotrf_(char *, 
 	    integer *, real *, integer *, integer *), spotrs_(char *, 
 	    integer *, integer *, real *, integer *, real *, integer *, 
@@ -1149,7 +1149,7 @@ static inline void zdotu_(doublecomplex *z, integer *n_, doublecomplex *x, integ
     if (*info != 0) {
 	i__1 = -(*info);
 	xerbla_("SPOSVXX", &i__1, (ftnlen)7);
-	return 0;
+	return;
     }
 
     if (equil) {
@@ -1189,7 +1189,7 @@ static inline void zdotu_(doublecomplex *z, integer *n_, doublecomplex *x, integ
 
 	    *rpvgrw = sla_porpvgrw_(uplo, info, &a[a_offset], lda, &af[
 		    af_offset], ldaf, &work[1]);
-	    return 0;
+	    return;
 	}
     }
 
@@ -1218,7 +1218,7 @@ static inline void zdotu_(doublecomplex *z, integer *n_, doublecomplex *x, integ
 	slascl2_(n, nrhs, &s[1], &x[x_offset], ldx);
     }
 
-    return 0;
+    return;
 
 /*     End of SPOSVXX */
 
